/*!
 * vue-use-parallax 1.0.0
 * Copyright 2020-preset tomieric<https://github.com/tomieric> All Rights Reserved
 * Licensed under MIT
 */

var VueUseParallax = (function (vue) {
  'use strict';

  /**
   *
   * vue hooks for parallax
   * @param {HTMLElement} el An area container that the mouse moves
   * @param {(Array<[] | HTMLElement>)} Scrolling elements
   */
  const useParallax = (el, children = []) => {
      const queue = [...children];
      const parallx = (el, x, y, offset = 10) => {
          el.style.transform = `translate(${x * offset / 0.5}px, ${y * offset / 0.5}px)`;
      };
      const subscribe = (offsetX, offsetY) => {
          queue.forEach((children) => {
              if (Array.isArray(children)) {
                  parallx(children[0], offsetX, offsetY, children[1]);
              }
              else {
                  parallx(children, offsetX, offsetY);
              }
          });
      };
      const setParallax = (children = []) => {
          queue.push(...children);
      };
      const scrollParallax = (e) => {
          const offsetX = e.clientX / el.clientWidth;
          const offsetY = e.clientY / el.clientHeight;
          subscribe(offsetX, offsetY);
      };
      // mousemove
      const startParallax = () => {
          resetParallax();
          el.addEventListener('mousemove', scrollParallax, false);
      };
      startParallax();
      // remove eventListener
      const resetParallax = () => el.removeEventListener('mousemove', scrollParallax, false);
      vue.onUnmounted(resetParallax);
      return {
          startParallax,
          setParallax,
          resetParallax
      };
  };

  return useParallax;

}(Vue));
